==> 3.5.12-core.tar: kdesdk/kbabel/kbabel/kbabelsplash.h <==
/* 
 *
 * $Id: kbabelsplash.h 1158450 2010-08-02 19:27:52Z tpearson $
 * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
 *		 2003 Stanislav Visnovsky <visnovsky@kde.org>
 *
 * This file is part of the KBabel project. It's taken from the K3b project, 
 * Copyright (C) 1998-2003 Sebastian Trueg <trueg@k3b.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * See the file "COPYING" for the exact licensing terms.

  In addition, as a special exception, the copyright holders give
  permission to link the code of this program with any edition of
  the Qt library by Trolltech AS, Norway (or with modified versions
  of Qt that use the same license as Qt), and distribute linked
  combinations including the two.  You must obey the GNU General
  Public License in all respects for all of the code used other than
  Qt. If you modify this file, you may extend this exception to
  your version of the file, but you are not obligated to do so.  If
  you do not wish to do so, delete this exception statement from
  your version.

 */


#ifndef KBABELSPLASH_H
#define KBABELSPLASH_H

#include <tqvbox.h>

class TQLabel;
class TQMouseEvent;
class TQPaintEvent;
class TQString;


class KBabelSplash : public QVBox
{
Q_OBJECT

 public:
  KBabelSplash( TQWidget* parent = 0, const char* name = 0 );
  ~KBabelSplash() { instance = 0; }
  
  static KBabelSplash* instance;

 protected:
  void mousePressEvent( TQMouseEvent* );
};

#endif

==> 3.5.13-core.tar: kdesdk/kbabel/kbabel/kbabelsplash.h <==
/* 
 *
 * $Id: kbabelsplash.h 1246260 2011-08-10 22:19:39Z tpearson $
 * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
 *		 2003 Stanislav Visnovsky <visnovsky@kde.org>
 *
 * This file is part of the KBabel project. It's taken from the K3b project, 
 * Copyright (C) 1998-2003 Sebastian Trueg <trueg@k3b.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * See the file "COPYING" for the exact licensing terms.

  In addition, as a special exception, the copyright holders give
  permission to link the code of this program with any edition of
  the TQt library by Trolltech AS, Norway (or with modified versions
  of TQt that use the same license as TQt), and distribute linked
  combinations including the two.  You must obey the GNU General
  Public License in all respects for all of the code used other than
  TQt. If you modify this file, you may extend this exception to
  your version of the file, but you are not obligated to do so.  If
  you do not wish to do so, delete this exception statement from
  your version.

 */


#ifndef KBABELSPLASH_H
#define KBABELSPLASH_H

#include <tqvbox.h>

class TQLabel;
class TQMouseEvent;
class TQPaintEvent;
class TQString;


class KBabelSplash : public TQVBox
{
Q_OBJECT
  TQ_OBJECT

 public:
  KBabelSplash( TQWidget* parent = 0, const char* name = 0 );
  ~KBabelSplash() { instance = 0; }
  
  static KBabelSplash* instance;

 protected:
  void mousePressEvent( TQMouseEvent* );
};

#endif
